//
//  ContentAllByThemeViewModel.swift
//  SodaLive
//
//  Created by klaus on 2/14/24.
//

import Foundation
import Combine

final class ContentAllByThemeViewModel: ObservableObject {
    enum Sort: String {
        case NEWEST, PRICE_HIGH, PRICE_LOW
    }
    
    private let repository = ContentRepository()
    private var subscription = Set<AnyCancellable>()
    
    @Published var errorMessage = ""
    @Published var isShowPopup = false
    @Published var isLoading = false
    
    @Published var theme = ""
    @Published var totalCount = 0
    @Published var sort = Sort.NEWEST {
        didSet {
            page = 1
            isLast = false
            getContentList()
        }
    }
    
    @Published var contentList: [GetAudioContentMainItem] = []
    
    var themeId = 0
    var page = 1
    var isLast = false
    private let pageSize = 10
    
    func getContentList() {
        if (!isLast && !isLoading) {
            isLoading = true
            
            repository.getAudioContentByTheme(
                themeId: themeId,
                page: page,
                size: pageSize,
                sort: sort
            )
            .sink { result in
                switch result {
                case .finished:
                    DEBUG_LOG("finish")
                case .failure(let error):
                    ERROR_LOG(error.localizedDescription)
                }
            } receiveValue: { [unowned self] response in
                let responseData = response.data
                
                do {
                    let jsonDecoder = JSONDecoder()
                    let decoded = try jsonDecoder.decode(ApiResponse<GetContentByThemeResponse>.self, from: responseData)
                    
                    if let data = decoded.data, decoded.success {
                        if page == 1 {
                            self.contentList.removeAll()
                        }
                        
                        if !data.items.isEmpty {
                            page += 1
                            self.theme = data.theme
                            self.totalCount = data.totalCount
                            self.contentList.append(contentsOf: data.items)
                        } else {
                            isLast = true
                        }
                    } else {
                        if let message = decoded.message {
                            self.errorMessage = message
                        } else {
                            self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                        }
                        
                        self.isShowPopup = true
                    }
                } catch {
                    self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                    self.isShowPopup = true
                }
                
                self.isLoading = false
            }
            .store(in: &subscription)
        }
    }
}
