//
//  ContentMainTabAlarmView.swift
//  SodaLive
//
//  Created by klaus on 2/22/25.
//

import SwiftUI

struct ContentMainTabAlarmView: View {
    
    @StateObject var viewModel = ContentMainTabAlarmViewModel()
    
    var body: some View {
        BaseView(isLoading: $viewModel.isLoading) {
            ScrollView(.vertical, showsIndicators: false) {
                VStack(spacing: 0) {
                    if !viewModel.bannerList.isEmpty {
                        ContentMainBannerViewV2(bannerList: viewModel.bannerList)
                            .padding(.horizontal, 13.3)
                    }
                    
                    if !viewModel.alarmThemeList.isEmpty {
                        ContentMainNewContentViewV2(
                            title: "새로운 알람",
                            onClickMore: {
                                AppState.shared
                                    .setAppStep(step: .newAlarmContentAll)
                            },
                            themeList: viewModel.alarmThemeList,
                            contentList: viewModel.newAlarmContentList
                        ) {
                            viewModel.getContentMainAlarm(theme: $0)
                        }
                        .padding(.top, 30)
                    }
                    
                    if !viewModel.eventBannerList.isEmpty {
                        SectionEventBannerView(items: viewModel.eventBannerList)
                            .padding(.top, 30)
                    }
                    
                    if !viewModel.curationList.isEmpty {
                        ContentMainCurationViewV2(curationList: viewModel.curationList)
                        .padding(.top, 30)
                    }
                }
                .onAppear {
                    viewModel.fetchData()
                }
            }
        }
        .popup(isPresented: $viewModel.isShowPopup, type: .toast, position: .bottom, autohideIn: 2) {
            HStack {
                Spacer()
                Text(viewModel.errorMessage)
                    .padding(.vertical, 13.3)
                    .frame(width: screenSize().width - 66.7, alignment: .center)
                    .font(.custom(Font.medium.rawValue, size: 12))
                    .background(Color.button)
                    .foregroundColor(Color.white)
                    .multilineTextAlignment(.leading)
                    .cornerRadius(20)
                    .padding(.bottom, 66.7)
                Spacer()
            }
        }
    }
}

#Preview {
    ContentMainTabAlarmView()
}
