//
//  LoginViewModel.swift
//  SodaLive
//
//  Created by klaus on 2023/08/09.
//

import Foundation
import Moya
import Combine

final class LoginViewModel: ObservableObject {
    private let repository = UserRepository()
    private var subscription = Set<AnyCancellable>()
    
    @Published var email = ""
    @Published var password = ""
    
    @Published var errorMessage = ""
    @Published var isShowPopup = false
    @Published var isLoading = false
    
    func login() {
        if email.isEmpty {
            self.errorMessage = "이메일을 입력해 주세요."
            self.isShowPopup = true
            return
        }
        
        if password.isEmpty {
            self.errorMessage = "비밀번호를 입력해 주세요."
            self.isShowPopup = true
            return
        }
        
        isLoading = true
        repository.login(request: LoginRequest(email: email, password: password))
            .sink { result in
                switch result {
                case .finished:
                    DEBUG_LOG("finish")
                case .failure(let error):
                    ERROR_LOG(error.localizedDescription)
                }
            } receiveValue: { response in
                self.isLoading = false
                let responseData = response.data
                do {
                    let jsonDecoder = JSONDecoder()
                    let decoded = try jsonDecoder.decode(ApiResponse<LoginResponse>.self, from: responseData)
                    
                    if let data = decoded.data, decoded.success {
                        UserDefaults.set(data.profileImage, forKey: .profileImage)
                        UserDefaults.set(data.nickname, forKey: .nickname)
                        UserDefaults.set(data.userId, forKey: .userId)
                        UserDefaults.set(data.email, forKey: .email)
                        UserDefaults.set(data.token, forKey: .token)
                    } else {
                        if let message = decoded.message {
                            self.errorMessage = message
                        } else {
                            self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                        }
                        
                        self.isShowPopup = true
                    }
                } catch {
                    self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                    self.isShowPopup = true
                }
            }
            .store(in: &subscription)
    }
}
